]> AND Private Git Repository - loba.git/blobdiff - process.h
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Rename process::load -> process::real_load.
[loba.git] / process.h
index 4e6ab240f8d73b6f3b15c9fe404568bb82bdc7e2..8f96fd8e188eac0719b938b21af2085c77be9daa 100644 (file)
--- a/process.h
+++ b/process.h
@@ -16,6 +16,7 @@
 #include <xbt/log.h>
 #include "communicator.h"
 #include "neighbor.h"
+#include "options.h"
 
 class process {
 public:
@@ -26,6 +27,9 @@ public:
     process(int argc, char* argv[]);
     virtual ~process();
 
+    double get_comp() const                { return comp; }
+    double get_real_load() const           { return real_load; }
+
     int run();
 
 protected:
@@ -35,9 +39,6 @@ protected:
     pneigh_type pneigh;         // list of pointers to neighbors that
                                 // we are free to reorder
 
-    // Returns the sum of "to_send" for all neighbors.
-    double sum_of_to_send() const;
-
     // Calls neighbor::print(verbose, logp, cat) for each member of neigh.
     void print_loads(bool verbose = false,
                      e_xbt_log_priority_t logp = xbt_log_priority_info,
@@ -50,7 +51,7 @@ protected:
 
 private:
     static double total_load_init; // sum of process loads at init
-    static double total_load_running; // summ of loads while running
+    static double total_load_running; // sum of loads while running
     static double total_load_exit; // sum of process loads at exit
 
     typedef MAP_TEMPLATE<m_host_t, neighbor*> rev_neigh_type;
@@ -64,19 +65,23 @@ private:
     int data_close_pending;     // number of "close" messages to wait
                                 // on data channel
     bool close_received;        // true if we received a "close" message
-    bool may_receive;           // true if there remains neighbors to listen for
     bool finalizing;            // true when finalize() is running
 
-    unsigned iter;              // counter of iterations
+    unsigned lb_iter;           // counter of load-balancing iterations
+    unsigned comp_iter;         // counter of computation iterations
+
+    double comp;                // total computing done so far (flops)
 
     double prev_load_broadcast; // used to ensure that we do not send
                                 // a same information messages
-    double load;                // current load
+    double real_load;           // current load
     double expected_load;       // expected load in bookkeeping mode
 
+    double& lb_load() { return opt::bookkeeping ? expected_load : real_load; }
+
     // The load balancing algorithm comes here...
     // Parameter "my_load" is the load to take into account for myself
// (may be load or expected load).
     // Returns the total load sent to neighbors.
     virtual double load_balance(double my_load);
 
@@ -86,11 +91,15 @@ private:
     // Send procedures, with helpers for bookkeeping mode or not
     void send1_no_bookkeeping(neighbor& nb);
     void send1_bookkeeping(neighbor& nb);
-    void send();
+    void send_all();
+
+    // Returns true if there remains neighbors to listen for
+    bool may_receive() { return ctrl_close_pending || data_close_pending; }
 
-    // Receive procedure: wait (or not) for a message to come.
-    enum recv_wait_mode { NO_WAIT = 0, WAIT, WAIT_FOR_CLOSE };
-    void receive(recv_wait_mode wait);
+    // Receive procedure
+    // Parameter "timeout" may be 0 for non-blocking operation, -1 for
+    // infinite waiting, or any positive timeout.
+    void receive(double timeout);
 
     // Finalize sends a "close" message to each neighbor and wait for
     // all of them to answer.
@@ -64,19 +65,23 @@ private:
     // The load balancing algorithm comes here...
     // Parameter "my_load" is the load to take into account for myself
-    // (may be load or expected load).
+    // (may be real load or expected load).
     // Returns the total load sent to neighbors.
     virtual double load_balance(double my_load);